Learn R Programming

RSizeBiased (version 0.1.0)

d_rsize_Weibull: Weibull size biased distribution of order \(r\).

Description

Calculates the density of the \(r-\)size biased Weibull distribution.

Usage

d_rsize_Weibull(x,TRpar,r)

Arguments

x

Grid points where the functional is being calculated.

TRpar

A vector of length 2, containing the shape and scale parameters of the distribution.

r

The size (order) of the distribution. The special cases \(r=1,2,3\) correspond to length, area, volume biased samples respectively and are the most frequently encountered in practice. The case \(r=0\) corresponds to random samples from the Weibull distribution.

Value

A vector of length equal to the length of \(x\).

Details

The \(r-\)size density of the observed biased sample \(X_1, \dots, X_n\) is defined by

$$f_r(x; \theta)=\frac{x^r f(x; \theta)}{E(X^r)}$$

where \(f(x; \theta)\) is the density of the Weibull distribution and \(\theta\) the vector of the shape and scale parameters of the distribution.

References

Economou et. al. (2021). Hypothesis testing for the population mean and variance based on r-size biased samples, under review.

See Also

p_rsize_Weibull, r_rsize_Weibull

Examples

Run this code
# NOT RUN {
# example of r-size Weibull distribution, r=0,1,2
x<- seq(0, 10, length=50)
dens.0.size<-d_rsize_Weibull(x,c(2,3),0)
dens.1.size<-d_rsize_Weibull(x,c(2,3),1)
dens.2.size<-d_rsize_Weibull(x,c(2,3),2)
plot(x, dens.0.size, type="l", ylab="r-denisty")
lines(x, dens.1.size, col=2)
lines(x, dens.2.size, col=3)
legend("topright",legend=c("r= 0","r= 1","r= 2"),
       col=c("black","red","green"),lty=c(1,1,1))
# }

Run the code above in your browser using DataLab