Learn R Programming

RSizeBiased (version 0.1.0)

p_rsize_Weibull: Weibull size biased c.d.f. of order \(r\).

Description

Calculates the cumulative distribution of the \(r-\)size biased Weibull distribution.

Usage

p_rsize_Weibull(q,TRpar,r)

Arguments

q

Points where the functional is being calculated.

TRpar

A vector of length 2, containing the shape and scale parameters of the distribution.

r

The size (order) of the distribution. The special cases \(r=1,2,3\) correspond to length, area, volume biased samples respectively and are the most frequently encountered in practice. The case \(r=0\) corresponds to random samples from the Weibull distribution.

Value

A vector of length equal to the lemgth of \(x\).

Details

The \(r-\)size c.d.f. of the Weibull density is defined by

$$F_r(y; \theta)=\int_{0}^{y} \frac{x^r f(x; \theta)}{E(X^r)} \,dx$$

where \(\theta\) is a bivariate vector with the the shape and scale of the Weibull distribution.

References

Economou et. al. (2021). Hypothesis testing for the population mean and variance based on r-size biased samples, under review.

See Also

d_rsize_Weibull, r_rsize_Weibull

Examples

Run this code
# NOT RUN {
# c.d.f of the r-size Weibull distribution, r=0,1,2 evalutated at a specific point x.
x<- 2
dist.0.size<-p_rsize_Weibull(x,c(2,3),0)
dist.1.size<-p_rsize_Weibull(x,c(2,3),1)
dist.2.size<-p_rsize_Weibull(x,c(2,3),2)
# }

Run the code above in your browser using DataLab