Learn R Programming

RSizeBiased (version 0.1.0)

r_rsize_Weibull: Weibull size biased random number generation of order \(r\) (modified).

Description

Provides a random sample of size \(n\) from the \(r-\)size biased Weibull distribution (modified).

Usage

r_rsize_Weibull(n,TRpar,r)

Arguments

n

Number of th sample data points to be provided.

TRpar

A vector of length 2, containing the shape and scale parameters of the distribution.

r

The size (order) of the distribution. The special cases \(r=1,2,3\) correspond to length, area, volume biased samples respectively and are the most frequently encountered in practice. The case \(r=0\) corresponds to random samples from the Weibull distribution.

Value

A vector of length \(n\) with the random sample.

Details

The \(r-\)size random number generator from the Weibull distribution is implemented based on a change-of-variable technique, to the standard gamma distribution as described by Gove and Patil (1998).

References

Gove J.H. and Patil G.P. (1998). Modeling the Basal Area-size Distribution of Forest Stands: A Compatible Approach. Forest Science, 44(2), 285-297.

See Also

d_rsize_Weibull, p_rsize_Weibull

Examples

Run this code
# NOT RUN {
#Random number geenration for the r-size Weibull distribution.
r_rsize_Weibull(100,c(2,3),1)
# }

Run the code above in your browser using DataLab